import { Module } from '@nuxt/types';
import { SanityClient } from '@sanity/client';

/**
 * Adapted from https://github.com/rexxars/picosanity
 */
interface SanityConfiguration {
    useCdn?: boolean;
    projectId: string;
    dataset?: string;
    withCredentials?: boolean;
    token?: string;
}
declare function getQs(query: string, params?: Record<string, any>): string;
declare function createClient(config: SanityConfiguration): {
    clone: () => any;
    /**
     * Perform a fetch using GROQ syntax.
     */
    fetch<T = unknown>(query: string, params?: Record<string, any> | undefined): Promise<T>;
};

/**
 * From https://github.com/sanity-io/sanity/tree/next/packages/groq
 */
declare const groq: (strings: TemplateStringsArray, ...keys: any[]) => string;

interface SanityModuleOptions extends Partial<SanityConfiguration> {
    /**
     * Use a micro-client that only supports making queries.
     * @default false
     */
    minimal?: boolean;
    /**
     * Register a global SanityImage component to generate correct Sanity image URLs
     * @default true
     */
    imageHelper?: boolean;
    /**
     * Register a global SanityContent component to serialize Sanity Portable Text
     * @default true
     */
    contentHelper?: boolean;
    /**
     * Configuration for any additional clients
     */
    additionalClients?: Record<string, Partial<SanityConfiguration>>;
}
declare const CONFIG_KEY = "sanity";
declare const HELPER_KEY = "$sanity";
declare const nuxtModule: Module<SanityModuleOptions>;
interface Client {
    client: SanityClient;
    fetch: ReturnType<typeof createClient>['fetch'];
    setToken: (token: string) => void;
}
declare type SanityHelper = Record<string, Client> & Client;
declare module '@nuxt/types' {
    interface NuxtConfig {
        [CONFIG_KEY]: SanityModuleOptions;
    }
    interface Configuration {
        [CONFIG_KEY]: SanityModuleOptions;
    }
    interface NuxtAppOptions {
        [HELPER_KEY]: SanityHelper;
    }
}
declare module 'vue/types/vue' {
    interface Vue {
        [HELPER_KEY]: SanityHelper;
    }
}
declare module 'vuex/types/index' {
    interface Store<S> {
        [HELPER_KEY]: SanityHelper;
    }
}

export default nuxtModule;
export { SanityConfiguration, SanityModuleOptions, createClient, getQs, groq };
